@@ -19,8 +19,13 @@ void odbc_connection::set_current_result(odbc_result* r) {
 }
 
 odbc_connection::odbc_connection(
-    std::string connection_string, std::string timezone, std::string encoding)
-    : current_result_(nullptr), encoding_(encoding) {
+    std::string connection_string,
+    std::string timezone,
+    std::string encoding,
+    bigint_map_t bigint_mapping)
+    : current_result_(nullptr),
+      encoding_(encoding),
+      bigint_mapping_(bigint_mapping) {
 
   if (!cctz::load_time_zone(timezone, &timezone_)) {
     Rcpp::stop("Error loading time zone (%s)", timezone);
@@ -72,4 +77,9 @@ bool odbc_connection::supports_transactions() const {
 
 cctz::time_zone odbc_connection::timezone() const { return timezone_; }
 std::string odbc_connection::encoding() const { return encoding_; }
+
+bigint_map_t odbc_connection::get_bigint_mapping() const {
+  return bigint_mapping_;
+}
+
 } // namespace odbc
